# -*- coding: utf-8 -*-
import sys
import unittest

sys.path.append("../laonlp")

loader = unittest.TestLoader()
testSuite = loader.discover("tests")
testRunner = unittest.TextTestRunner(verbosity=1)
testRunner.run(testSuite)



# -*- coding: utf-8 -*-
import csv
import os

from laonlp.corpus import mopt_dict

def dictionary(word: str, src: str, target: str):
    if src == "lao" and target == "eng":
        _temp = mopt_dict.get_lao_eng()
        if word not in list(_temp.keys()):
            return None
        return _temp[word]
    elif src == "eng" and target == "lao":
        _temp = mopt_dict.get_eng_lao()
        if word not in list(_temp.keys()):
            return None
        return _temp[word]
    else:
        return word


# -*- coding: utf-8 -*-
import os
from typing import List
from laonlp.corpus import laonlp_path
corpus_path = os.path.join(laonlp_path, "corpus")


def lao_dictionary() -> List[str]:
    path=os.path.join(corpus_path, "Lao-Dictionary.txt")
    with open(path, "r", encoding="utf-8-sig") as f:
        return [i.strip() for i in f.readlines() if i[0]!="#"]


def lo_spellcheckdict() -> List[str]:
    path=os.path.join(corpus_path, "lo_spellcheck_dict.txt")
    with open(path, "r", encoding="utf-8-sig") as f:
        return [i.strip() for i in f.readlines() if i[0]!="#"]


def lo_wannaphongdict() -> List[str]:
    path=os.path.join(corpus_path, "lao-wannaphong.txt")
    with open(path, "r", encoding="utf-8-sig") as f:
        return [i.strip() for i in f.readlines() if i[0]!="#"]


def lo_wiktionarydict() -> List[str]:
    path=os.path.join(corpus_path, "wiktionary-20210720.txt")
    with open(path, "r", encoding="utf-8-sig") as f:
        return [i.strip() for i in f.readlines() if i[0]!="#"]


def lao_words() -> List[str]:
    return list(set(lao_dictionary()+lo_spellcheckdict()+lo_wannaphongdict()+lo_wiktionarydict()))



# -*- coding: utf-8 -*-
import csv
import os

from laonlp.corpus import laonlp_path
corpus_path = os.path.join(laonlp_path, "corpus", "lao-eng-dictionary.csv")
list_data=[]
with open(corpus_path,encoding="utf-8-sig") as csvfile:
    reader = csv.DictReader(csvfile)
    for row in reader:
        list_data.append(row)


def get_lao_eng():
    _w = {}
    for i in list_data:
        _w[i['LaoWord']] = i['English']
    return _w


def get_eng_lao():
    _w = {}
    for i in list_data:
        _w[i['English']] = i['LaoWord']
    return _w


def get_pronunciation():
    _w = {}
    for i in list_data:
        _w[i['LaoWord']] = i['Pronunciation']
    return _w


def get_type():
    _w = {}
    for i in list_data:
        _w[i['LaoWord']] = i['Type']
    return _w



# -*- coding: utf-8 -*-
__all__ = [
    "word_dictionary",
]

def word_dictionary(word: str, src: str, target: str, name: str = "mopt_laos"):
    from laonlp.translate.mopt_dict import dictionary
    return dictionary(word, src, target)


# -*- coding: utf-8 -*-

import unittest
from laonlp.tokenize import word_tokenize, sent_tokenize

class TestTokenizePackage(unittest.TestCase):
    def test_word_tokenize(self):
        self.assertIsNotNone(word_tokenize("ພາສາລາວໃນປັດຈຸບັນ."))

    def test_sent_tokenize(self):
        self.assertIsNotNone(sent_tokenize("ພາສາລາວໃນປັດຈຸບັນ.ນະຄອນຫຼວງວຽງຈັນ"))



# -*- coding: utf-8 -*-
from typing import List
from pythainlp.tokenize import Tokenizer
from laonlp.corpus import lao_words

_word = Tokenizer(lao_words(), engine="mm")


def word_tokenize(sent: str) -> List[str]:
    """
    Lao word tokenize

    :param str sent: lao text
    :return: returns a list of lao words
    :rtype: list
    """
    return _word.word_tokenize(sent)


def sent_tokenize(txt: str) -> List[str]:
    """
    Sentence tokenizer.

    Lao Text to sentence

    :param str sent: lao text
    :return: returns a list of lao sentence
    :rtype: list
    """
    return txt.split(".")



# -*- coding: utf-8 -*-
from laonlp.tokenize import *
from laonlp.corpus import *
from laonlp.transliterate import *

TONE_MARKS = "່້"+"໊໋"
CONSONANTS = "ກຂຄງຈສຊຍດຕຖທນບປຜຝພຟມຢຣລວຫອຮ"
VOWELS_COMBINING = "ັ"+"ິີ"+"ຶືຸ"+"ູົໍ"
VOWELS = "ະັາ"+"ຳິີ"+"ຶືຸ"+"ູົຼ"+"ຽເແ"+"ໂໃໄ"+"ໍ"